<div align="center">

<p alig="center">

<img src="images/pixano_logo.png" alt="Pixano" height="100"/>

**Data Centric AI Building Blocks for Computer Vision Application**

[![License](https://img.shields.io/badge/license-CeCILL--C-blue.svg)](LICENSE)
![Python version](https://img.shields.io/badge/python-3.10+-important)


**UNDER ACTIVE DEVELOPMENT, SUBJECT TO API CHANGE!**

</p>

</div>

<hr/>

## Installation

```shell
pip install pixano==0.1.0
```
